summaryrefslogtreecommitdiffstats
path: root/extra/kde301
diff options
context:
space:
mode:
Diffstat (limited to 'extra/kde301')
-rw-r--r--extra/kde301/kaccelaction.h54
-rw-r--r--extra/kde301/kaccelbase.h38
-rw-r--r--extra/kde301/kicontheme.h48
-rw-r--r--extra/kde301/kkeyserver_x11.h44
-rw-r--r--extra/kde301/konsole_part.h54
-rw-r--r--extra/kde301/krecentdirs.h8
-rw-r--r--extra/kde301/ksycocafactory.h16
-rw-r--r--extra/kde301/ktoolbarbutton.h70
-rw-r--r--extra/kde301/kurifilter.h70
9 files changed, 201 insertions, 201 deletions
diff --git a/extra/kde301/kaccelaction.h b/extra/kde301/kaccelaction.h
index 139d7f7..762b98f 100644
--- a/extra/kde301/kaccelaction.h
+++ b/extra/kde301/kaccelaction.h
@@ -29,7 +29,7 @@
class KAccelBase;
-class QObject;
+class TQObject;
class KConfig;
class KConfigBase;
@@ -68,37 +68,37 @@ class KAccelAction
public:
KAccelAction();
KAccelAction( const KAccelAction& );
- KAccelAction( const QString& sName, const QString& sLabel, const QString& sWhatsThis,
+ KAccelAction( const TQString& sName, const TQString& sLabel, const TQString& sWhatsThis,
const KShortcut& cutDef3, const KShortcut& cutDef4,
- const QObject* pObjSlot, const char* psMethodSlot,
+ const TQObject* pObjSlot, const char* psMethodSlot,
bool bConfigurable, bool bEnabled );
~KAccelAction();
void clear();
- bool init( const QString& sName, const QString& sLabel, const QString& sWhatsThis,
+ bool init( const TQString& sName, const TQString& sLabel, const TQString& sWhatsThis,
const KShortcut& cutDef3, const KShortcut& cutDef4,
- const QObject* pObjSlot, const char* psMethodSlot,
+ const TQObject* pObjSlot, const char* psMethodSlot,
bool bConfigurable, bool bEnabled );
KAccelAction& operator=( const KAccelAction& );
- const QString& name() const { return m_sName; }
- const QString& label() const { return m_sLabel; }
- const QString& whatsThis() const { return m_sWhatsThis; }
+ const TQString& name() const { return m_sName; }
+ const TQString& label() const { return m_sLabel; }
+ const TQString& whatsThis() const { return m_sWhatsThis; }
const KShortcut& shortcut() const { return m_cut; }
const KShortcut& shortcutDefault() const;
const KShortcut& shortcutDefault3() const { return m_cutDefault3; }
const KShortcut& shortcutDefault4() const { return m_cutDefault4; }
- const QObject* objSlotPtr() const { return m_pObjSlot; }
+ const TQObject* objSlotPtr() const { return m_pObjSlot; }
const char* methodSlotPtr() const { return m_psMethodSlot; }
bool isConfigurable() const { return m_bConfigurable; }
bool isEnabled() const { return m_bEnabled; }
- void setName( const QString& );
- void setLabel( const QString& );
- void setWhatsThis( const QString& );
+ void setName( const TQString& );
+ void setLabel( const TQString& );
+ void setWhatsThis( const TQString& );
bool setShortcut( const KShortcut& rgCuts );
- void setSlot( const QObject* pObjSlot, const char* psMethodSlot );
+ void setSlot( const TQObject* pObjSlot, const char* psMethodSlot );
void setConfigurable( bool );
void setEnabled( bool );
@@ -110,19 +110,19 @@ class KAccelAction
void clearShortcut();
bool contains( const KKeySequence& );
- QString toString() const;
- QString toStringInternal() const;
+ TQString toString() const;
+ TQString toStringInternal() const;
static bool useFourModifierKeys();
static void useFourModifierKeys( bool );
protected:
- QString m_sName,
+ TQString m_sName,
m_sLabel,
m_sWhatsThis;
KShortcut m_cut;
KShortcut m_cutDefault3, m_cutDefault4;
- const QObject* m_pObjSlot;
+ const TQObject* m_pObjSlot;
const char* m_psMethodSlot;
bool m_bConfigurable,
m_bEnabled;
@@ -153,28 +153,28 @@ class KAccelActions
void clear();
bool init( const KAccelActions& );
- bool init( KConfigBase& config, const QString& sGroup );
+ bool init( KConfigBase& config, const TQString& sGroup );
void updateShortcuts( KAccelActions& );
- int actionIndex( const QString& sAction ) const;
+ int actionIndex( const TQString& sAction ) const;
KAccelAction* actionPtr( uint );
const KAccelAction* actionPtr( uint ) const;
- KAccelAction* actionPtr( const QString& sAction );
- const KAccelAction* actionPtr( const QString& sAction ) const;
+ KAccelAction* actionPtr( const TQString& sAction );
+ const KAccelAction* actionPtr( const TQString& sAction ) const;
KAccelAction* actionPtr( KKeySequence cut );
KAccelAction& operator []( uint );
const KAccelAction& operator []( uint ) const;
- KAccelAction* insert( const QString& sAction, const QString& sLabel, const QString& sWhatsThis,
+ KAccelAction* insert( const TQString& sAction, const TQString& sLabel, const TQString& sWhatsThis,
const KShortcut& rgCutDefaults3, const KShortcut& rgCutDefaults4,
- const QObject* pObjSlot = 0, const char* psMethodSlot = 0,
+ const TQObject* pObjSlot = 0, const char* psMethodSlot = 0,
bool bConfigurable = true, bool bEnabled = true );
- KAccelAction* insert( const QString& sName, const QString& sLabel );
- bool remove( const QString& sAction );
+ KAccelAction* insert( const TQString& sName, const TQString& sLabel );
+ bool remove( const TQString& sAction );
- bool readActions( const QString& sConfigGroup = "Shortcuts", KConfigBase* pConfig = 0 );
- bool writeActions( const QString& sConfigGroup = "Shortcuts", KConfigBase* pConfig = 0,
+ bool readActions( const TQString& sConfigGroup = "Shortcuts", KConfigBase* pConfig = 0 );
+ bool writeActions( const TQString& sConfigGroup = "Shortcuts", KConfigBase* pConfig = 0,
bool bWriteAll = false, bool bGlobal = false ) const;
void emitKeycodeChanged();
diff --git a/extra/kde301/kaccelbase.h b/extra/kde301/kaccelbase.h
index 1a80eee..86889d5 100644
--- a/extra/kde301/kaccelbase.h
+++ b/extra/kde301/kaccelbase.h
@@ -29,8 +29,8 @@
#include "kaccelaction.h"
#include "kkeyserver_x11.h"
-class QPopupMenu;
-class QWidget;
+class TQPopupMenu;
+class TQWidget;
//----------------------------------------------------
@@ -132,13 +132,13 @@ class KAccelBase
KAccelActions& actions();
bool isEnabled() const;
- KAccelAction* actionPtr( const QString& sAction );
- const KAccelAction* actionPtr( const QString& sAction ) const;
+ KAccelAction* actionPtr( const TQString& sAction );
+ const KAccelAction* actionPtr( const TQString& sAction ) const;
KAccelAction* actionPtr( const KKey& key );
KAccelAction* actionPtr( const KKeyServer::Key& key );
- const QString& configGroup() const { return m_sConfigGroup; }
- void setConfigGroup( const QString& group );
+ const TQString& configGroup() const { return m_sConfigGroup; }
+ void setConfigGroup( const TQString& group );
void setConfigGlobal( bool global );
virtual void setEnabled( bool bEnabled ) = 0;
bool getAutoUpdate() { return m_bAutoUpdate; }
@@ -148,21 +148,21 @@ class KAccelBase
// Procedures for manipulating Actions.
//void clearActions();
- KAccelAction* insert( const QString& sName, const QString& sDesc );
+ KAccelAction* insert( const TQString& sName, const TQString& sDesc );
KAccelAction* insert(
- const QString& sAction, const QString& sDesc, const QString& sHelp,
+ const TQString& sAction, const TQString& sDesc, const TQString& sHelp,
const KShortcut& rgCutDefaults3, const KShortcut& rgCutDefaults4,
- const QObject* pObjSlot, const char* psMethodSlot,
+ const TQObject* pObjSlot, const char* psMethodSlot,
bool bConfigurable = true, bool bEnabled = true );
- bool remove( const QString& sAction );
- bool setActionSlot( const QString& sAction, const QObject* pObjSlot, const char* psMethodSlot );
+ bool remove( const TQString& sAction );
+ bool setActionSlot( const TQString& sAction, const TQObject* pObjSlot, const char* psMethodSlot );
bool updateConnections();
- bool setShortcut( const QString& sAction, const KShortcut& cut );
+ bool setShortcut( const TQString& sAction, const KShortcut& cut );
// Modify individual Action sub-items
- bool setActionEnabled( const QString& sAction, bool bEnable );
+ bool setActionEnabled( const TQString& sAction, bool bEnable );
/**
* Read all key associations from @p config, or (if @p config
@@ -181,13 +181,13 @@ class KAccelBase
*/
void writeSettings( KConfigBase* pConfig = 0 ) const;
- QPopupMenu* createPopupMenu( QWidget* pParent, const KKeySequence& );
+ TQPopupMenu* createPopupMenu( TQWidget* pParent, const KKeySequence& );
// Protected methods
protected:
void slotRemoveAction( KAccelAction* );
- void createKeyList( QValueVector<struct X>& rgKeys );
+ void createKeyList( TQValueVector<struct X>& rgKeys );
bool insertConnection( KAccelAction* );
bool removeConnection( KAccelAction* );
@@ -208,15 +208,15 @@ class KAccelBase
ActionInfo( KAccelAction* _pAction, uint _iSeq, uint _iVariation )
{ pAction = _pAction; iSeq = _iSeq; iVariation = _iVariation; }
};
- typedef QMap<KKeyServer::Key, ActionInfo> KKeyToActionMap;
+ typedef TQMap<KKeyServer::Key, ActionInfo> KKeyToActionMap;
KAccelActions m_rgActions;
KKeyToActionMap m_mapKeyToAction;
- QValueList<KAccelAction*> m_rgActionsNonUnique;
- bool m_bNativeKeys; // Use native key codes instead of Qt codes
+ TQValueList<KAccelAction*> m_rgActionsNonUnique;
+ bool m_bNativeKeys; // Use native key codes instead of TQt codes
bool m_bEnabled;
bool m_bConfigIsGlobal;
- QString m_sConfigGroup;
+ TQString m_sConfigGroup;
bool m_bAutoUpdate;
KAccelAction* mtemp_pActionRemoving;
diff --git a/extra/kde301/kicontheme.h b/extra/kde301/kicontheme.h
index c52e43d..4624c23 100644
--- a/extra/kde301/kicontheme.h
+++ b/extra/kde301/kicontheme.h
@@ -75,7 +75,7 @@ public:
/**
* The full path of the icon.
*/
- QString path;
+ TQString path;
private:
KIconPrivate *d;
@@ -94,53 +94,53 @@ public:
/**
* Load an icon theme by name.
*/
- KIconTheme(const QString& name, const QString& appName=QString::null);
+ KIconTheme(const TQString& name, const TQString& appName=TQString::null);
~KIconTheme();
/**
* The stylized name of the icon theme.
*/
- QString name() const { return mName; }
+ TQString name() const { return mName; }
/**
* A description for the icon theme.
*/
- QString description() const { return mDesc; }
+ TQString description() const { return mDesc; }
/**
* Return the name of the "example" icon.
*/
- QString example() const;
+ TQString example() const;
/**
* Return the name of the screenshot.
*/
- QString screenshot() const;
+ TQString screenshot() const;
/**
* Returns the name of this theme's link overlay.
*/
- QString linkOverlay() const;
+ TQString linkOverlay() const;
/**
* Returns the name of this theme's zip overlay.
*/
- QString zipOverlay() const;
+ TQString zipOverlay() const;
/**
* Returns the name of this theme's lock overlay.
*/
- QString lockOverlay() const;
+ TQString lockOverlay() const;
/**
* Returns the toplevel theme directory.
*/
- QString dir() const { return mDir; }
+ TQString dir() const { return mDir; }
/**
* The themes this icon theme falls back on.
*/
- QStringList inherits() const { return mInherits; }
+ TQStringList inherits() const { return mInherits; }
/**
* The icon theme exists?
@@ -148,7 +148,7 @@ public:
bool isValid() const;
/**
- * The minimum display depth required for this theme. This can either
+ * The minimum display depth retquired for this theme. This can either
* be 8 or 32.
*/
int depth() const { return mDepth; }
@@ -163,17 +163,17 @@ public:
/**
* Query available sizes for a group.
*/
- QValueList<int> querySizes(KIcon::Group group) const;
+ TQValueList<int> querySizes(KIcon::Group group) const;
/**
* Query available icons for a size and context.
*/
- QStringList queryIcons(int size, KIcon::Context context = KIcon::Any) const;
+ TQStringList queryIcons(int size, KIcon::Context context = KIcon::Any) const;
/**
* Query available icons for a context and preferred size.
*/
- QStringList queryIconsByContext(int size, KIcon::Context context = KIcon::Any) const;
+ TQStringList queryIconsByContext(int size, KIcon::Context context = KIcon::Any) const;
/**
@@ -186,32 +186,32 @@ public:
* @return A KIcon class that describes the icon. If an icon is found,
* @ref #KIcon::isValid will return true, and false otherwise.
*/
- KIcon iconPath(const QString& name, int size, KIcon::MatchType match) const;
+ KIcon iconPath(const TQString& name, int size, KIcon::MatchType match) const;
/**
* List all icon themes installed on the system, global and local.
*/
- static QStringList list();
+ static TQStringList list();
/**
* Returns the current icon theme.
*/
- static QString current();
+ static TQString current();
static void reconfigure();
private:
int mDefSize[8];
- QValueList<int> mSizes[8];
+ TQValueList<int> mSizes[8];
int mDepth;
- QString mDir, mName, mDesc;
- QStringList mInherits;
-// QPtrList<KIconThemeDir> mDirs;
+ TQString mDir, mName, mDesc;
+ TQStringList mInherits;
+// TQPtrList<KIconThemeDir> mDirs;
KIconThemePrivate *d;
- static QString *_theme;
- static QStringList *_theme_list;
+ static TQString *_theme;
+ static TQStringList *_theme_list;
};
#endif
diff --git a/extra/kde301/kkeyserver_x11.h b/extra/kde301/kkeyserver_x11.h
index faeb99c..c6250b2 100644
--- a/extra/kde301/kkeyserver_x11.h
+++ b/extra/kde301/kkeyserver_x11.h
@@ -17,26 +17,26 @@ namespace KKeyServer
{ m_sym = 0; }
Sym( uint sym )
{ m_sym = sym; }
- Sym( const QString& s )
+ Sym( const TQString& s )
{ init( s ); }
- bool initQt( int keyQt );
- bool init( const QString& );
+ bool initTQt( int keyTQt );
+ bool init( const TQString& );
int qt() const;
- QString toStringInternal() const;
- QString toString() const;
+ TQString toStringInternal() const;
+ TQString toString() const;
- uint getModsRequired() const;
+ uint getModsRetquired() const;
uint getSymVariation() const;
operator uint() const { return m_sym; }
Sym& operator =( uint sym ) { m_sym = sym; return *this; }
private:
- QString toString( bool bUserSpace ) const;
+ TQString toString( bool bUserSpace ) const;
- static void capitalizeKeyname( QString& );
+ static void capitalizeKeyname( TQString& );
};
struct Key
@@ -47,17 +47,17 @@ namespace KKeyServer
uint m_mod;
uint m_sym;
- bool init( const KKey& key, bool bQt );
+ bool init( const KKey& key, bool bTQt );
bool isNative() const { return m_code != CODE_FOR_QT; }
uint code() const { return m_code; }
uint mod() const { return m_mod; }
uint sym() const { return m_sym; }
- int keyCodeQt() const { return (int) m_sym; }
+ int keyCodeTQt() const { return (int) m_sym; }
- void setKeycodeQt( int keyQt )
- { m_code = CODE_FOR_QT; m_sym = keyQt; }
+ void setKeycodeTQt( int keyTQt )
+ { m_code = CODE_FOR_QT; m_sym = keyTQt; }
Key& operator =( const KKeyNative& key );
int compare( const Key& ) const;
@@ -79,7 +79,7 @@ namespace KKeyServer
Variations() { m_nVariations = 0; }
- void init( const KKey&, bool bQt );
+ void init( const KKey&, bool bTQt );
uint count() const { return m_nVariations; }
const Key& key( uint i ) const { return m_rgkey[i]; }
@@ -109,23 +109,23 @@ namespace KKeyServer
*/
uint accelModMaskX();
- bool keyQtToSym( int keyQt, uint& sym );
- bool keyQtToMod( int keyQt, uint& mod );
- bool symToKeyQt( uint sym, int& keyQt );
+ bool keyTQtToSym( int keyTQt, uint& sym );
+ bool keyTQtToMod( int keyTQt, uint& mod );
+ bool symToKeyTQt( uint sym, int& keyTQt );
- bool modToModQt( uint mod, int& modQt );
+ bool modToModTQt( uint mod, int& modTQt );
bool modToModX( uint mod, uint& modX );
- bool modXToModQt( uint modX, int& modQt );
+ bool modXToModTQt( uint modX, int& modTQt );
bool modXToMod( uint modX, uint& mod );
bool codeXToSym( uchar codeX, uint modX, uint& symX );
- QString modToStringInternal( uint mod );
- QString modToStringUser( uint mod );
+ TQString modToStringInternal( uint mod );
+ TQString modToStringUser( uint mod );
- bool stringToSymMod( const QString&, uint& sym, uint& mod );
+ bool stringToSymMod( const TQString&, uint& sym, uint& mod );
- void keyQtToKeyX( uint keyCombQt, unsigned char *pKeyCodeX, uint *pKeySymX, uint *pKeyModX );
+ void keyTQtToKeyX( uint keyCombTQt, unsigned char *pKeyCodeX, uint *pKeySymX, uint *pKeyModX );
};
#endif // !_KKEYSERVER_X11_H
diff --git a/extra/kde301/konsole_part.h b/extra/kde301/konsole_part.h
index ba89800..6aba706 100644
--- a/extra/kde301/konsole_part.h
+++ b/extra/kde301/konsole_part.h
@@ -34,10 +34,10 @@
class KInstance;
class konsoleBrowserExtension;
-class QPushButton;
-class QSpinBox;
+class TQPushButton;
+class TQSpinBox;
class KPopupMenu;
-class QCheckBox;
+class TQCheckBox;
class KRootPixmap;
class KToggleAction;
class KSelectAction;
@@ -51,10 +51,10 @@ public:
konsoleFactory();
virtual ~konsoleFactory();
- virtual KParts::Part* createPartObject(QWidget *parentWidget = 0, const char *widgetName = 0,
- QObject* parent = 0, const char* name = 0,
+ virtual KParts::Part* createPartObject(TQWidget *parentWidget = 0, const char *widgetName = 0,
+ TQObject* parent = 0, const char* name = 0,
const char* classname = "KParts::Part",
- const QStringList &args = QStringList());
+ const TQStringList &args = TQStringList());
static KInstance *instance();
@@ -69,12 +69,12 @@ class konsolePart: public KParts::ReadOnlyPart, public TerminalInterface
{
Q_OBJECT
public:
- konsolePart(QWidget *parentWidget, const char *widgetName, QObject * parent, const char *name, const char *classname = 0);
+ konsolePart(TQWidget *parentWidget, const char *widgetName, TQObject * parent, const char *name, const char *classname = 0);
virtual ~konsolePart();
signals:
void processExited();
- void receivedData( const QString& s );
+ void receivedData( const TQString& s );
protected:
virtual bool openURL( const KURL & url );
virtual bool openFile() {return false;} // never used
@@ -84,7 +84,7 @@ signals:
protected slots:
void showShell();
void slotProcessExited();
- void slotReceivedData( const QString& s );
+ void slotReceivedData( const TQString& s );
// void doneSession(TESession*);
void sessionDestroyed();
@@ -93,7 +93,7 @@ signals:
void enableMasterModeConnections();
private slots:
- void emitOpenURLRequest(const QString &url);
+ void emitOpenURLRequest(const TQString &url);
void readProperties();
void saveProperties();
@@ -130,11 +130,11 @@ signals:
// void setSchema(ColorSchema* s);
void updateKeytabMenu();
- bool doOpenStream( const QString& );
- bool doWriteStream( const QByteArray& );
+ bool doOpenStream( const TQString& );
+ bool doWriteStream( const TQByteArray& );
bool doCloseStream();
- QWidget* parentWidget;
+ TQWidget* parentWidget;
// TEWidget* te;
// TESession* se;
// ColorSchemaList* colors;
@@ -154,13 +154,13 @@ signals:
KPopupMenu* m_options;
KPopupMenu* m_popupMenu;
- QFont defaultFont;
+ TQFont defaultFont;
- QString pmPath; // pixmap path
- QString s_schema;
- QString s_kconfigSchema;
- QString s_word_seps; // characters that are considered part of a word
- QString fontNotFound_par;
+ TQString pmPath; // pixmap path
+ TQString s_schema;
+ TQString s_kconfigSchema;
+ TQString s_word_seps; // characters that are considered part of a word
+ TQString fontNotFound_par;
bool b_framevis:1;
bool b_histEnabled:1;
@@ -177,10 +177,10 @@ signals:
public:
// these are the implementations for the TermEmuInterface
// functions...
- void startProgram( const QString& program,
- const QStrList& args );
- void showShellInDir( const QString& dir );
- void sendInput( const QString& text );
+ void startProgram( const TQString& program,
+ const TQStrList& args );
+ void showShellInDir( const TQString& dir );
+ void sendInput( const TQString& text );
};
//////////////////////////////////////////////////////////////////////
@@ -191,7 +191,7 @@ public:
public:
HistoryTypeDialog(const HistoryType& histType,
unsigned int histSize,
- QWidget *parent);
+ TQWidget *parent);
public slots:
void slotDefault();
@@ -202,9 +202,9 @@ public slots:
bool isOn() const;
protected:
- QCheckBox* m_btnEnable;
- QSpinBox* m_size;
- QPushButton* m_setUnlimited;
+ TQCheckBox* m_btnEnable;
+ TQSpinBox* m_size;
+ TQPushButton* m_setUnlimited;
};*/
//////////////////////////////////////////////////////////////////////
diff --git a/extra/kde301/krecentdirs.h b/extra/kde301/krecentdirs.h
index 71f771b..656f4f9 100644
--- a/extra/kde301/krecentdirs.h
+++ b/extra/kde301/krecentdirs.h
@@ -16,7 +16,7 @@
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSETQUENTIAL
* DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
* OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
* HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
@@ -52,17 +52,17 @@ public:
* Returns a list of directories associated with this file-class.
* The most recently used directory is at the front of the list.
*/
- static QStringList list(const QString &fileClass);
+ static TQStringList list(const TQString &fileClass);
/**
* Returns the most recently used directory accociated with this file-class.
*/
- static QString dir(const QString &fileClass);
+ static TQString dir(const TQString &fileClass);
/**
* Associates @p directory with @p fileClass
*/
- static void add(const QString &fileClass, const QString &directory);
+ static void add(const TQString &fileClass, const TQString &directory);
};
#endif
diff --git a/extra/kde301/ksycocafactory.h b/extra/kde301/ksycocafactory.h
index af33ca8..6bce731 100644
--- a/extra/kde301/ksycocafactory.h
+++ b/extra/kde301/ksycocafactory.h
@@ -25,12 +25,12 @@
#include <qdict.h>
#include <qptrlist.h>
class KSycoca;
-class QStringList;
-class QString;
+class TQStringList;
+class TQString;
class KSycocaDict;
class KSycocaResourceList;
-typedef QDict<KSycocaEntry::Ptr> KSycocaEntryDict;
+typedef TQDict<KSycocaEntry::Ptr> KSycocaEntryDict;
/**
* @internal
@@ -65,7 +65,7 @@ public:
* Construct an entry from a config file.
* To be implemented in the real factories.
*/
- virtual KSycocaEntry *createEntry(const QString &file, const char *resource) = 0;
+ virtual KSycocaEntry *createEntry(const TQString &file, const char *resource) = 0;
/**
* Add an entry
@@ -93,7 +93,7 @@ public:
* Don't forget to call the parent first when you override
* this function.
*/
- virtual void save(QDataStream &str);
+ virtual void save(TQDataStream &str);
/**
* Writes out a header to the stream 'str'.
@@ -102,7 +102,7 @@ public:
* Don't forget to call the parent first when you override
* this function.
*/
- virtual void saveHeader(QDataStream &str);
+ virtual void saveHeader(TQDataStream &str);
/**
* @return the resources for which this factory is responsible.
@@ -116,7 +116,7 @@ protected:
int m_sycocaDictOffset;
int m_beginEntryOffset;
int m_endEntryOffset;
- QDataStream *m_str;
+ TQDataStream *m_str;
KSycocaResourceList *m_resourceList;
KSycocaEntryDict *m_entryDict;
@@ -126,7 +126,7 @@ protected:
};
// This, instead of a typedef, allows to declare "class ..." in header files
-class KSycocaFactoryList : public QPtrList<KSycocaFactory>
+class KSycocaFactoryList : public TQPtrList<KSycocaFactory>
{
public:
KSycocaFactoryList() { }
diff --git a/extra/kde301/ktoolbarbutton.h b/extra/kde301/ktoolbarbutton.h
index bb6806b..612cb32 100644
--- a/extra/kde301/ktoolbarbutton.h
+++ b/extra/kde301/ktoolbarbutton.h
@@ -33,16 +33,16 @@
class KToolBar;
class KToolBarButtonPrivate;
class KInstance;
-class QEvent;
-class QPopupMenu;
-class QPainter;
+class TQEvent;
+class TQPopupMenu;
+class TQPainter;
/**
* A toolbar button. This is used internally by @ref KToolBar, use the
* KToolBar methods instead.
* @internal
*/
-class KToolBarButton : public QToolButton
+class KToolBarButton : public TQToolButton
{
Q_OBJECT
@@ -58,8 +58,8 @@ public:
* @param name This button's internal name
* @param txt This button's text (in a tooltip or otherwise)
*/
- KToolBarButton(const QString& icon, int id, QWidget *parent,
- const char *name=0L, const QString &txt=QString::null,
+ KToolBarButton(const TQString& icon, int id, TQWidget *parent,
+ const char *name=0L, const TQString &txt=TQString::null,
KInstance *_instance = KGlobal::instance());
/**
@@ -73,8 +73,8 @@ public:
* @param name This button's internal name
* @param txt This button's text (in a tooltip or otherwise)
*/
- KToolBarButton(const QPixmap& pixmap, int id, QWidget *parent,
- const char *name=0L, const QString &txt=QString::null);
+ KToolBarButton(const TQPixmap& pixmap, int id, TQWidget *parent,
+ const char *name=0L, const TQString &txt=TQString::null);
/**
* Construct a separator button
@@ -82,7 +82,7 @@ public:
* @param parent This button's parent
* @param name This button's internal name
*/
- KToolBarButton(QWidget *parent=0L, const char *name=0L);
+ KToolBarButton(TQWidget *parent=0L, const char *name=0L);
/**
* Standard destructor
@@ -99,8 +99,8 @@ public:
*
* @param pixmap The active pixmap
*/
- // this one is from QButton, so #ifdef-ing it out doesn't break BC
- virtual void setPixmap(const QPixmap &pixmap);
+ // this one is from TQButton, so #ifdef-ing it out doesn't break BC
+ virtual void setPixmap(const TQPixmap &pixmap);
/**
* @deprecated
@@ -109,7 +109,7 @@ public:
*
* @param pixmap The pixmap to use as the default (normal) one
*/
- void setDefaultPixmap(const QPixmap& pixmap);
+ void setDefaultPixmap(const TQPixmap& pixmap);
/**
* @deprecated
@@ -118,7 +118,7 @@ public:
*
* @param pixmap The pixmap to use when disabled
*/
- void setDisabledPixmap(const QPixmap& pixmap);
+ void setDisabledPixmap(const TQPixmap& pixmap);
#endif
/**
@@ -127,7 +127,7 @@ public:
*
* @param text The button (or tooltip) text
*/
- virtual void setText(const QString &text);
+ virtual void setText(const TQString &text);
/**
* Set the icon for this button. The icon will be loaded internally
@@ -135,18 +135,18 @@ public:
*
* @param icon The name of the icon
*/
- virtual void setIcon(const QString &icon);
+ virtual void setIcon(const TQString &icon);
- virtual void setIcon( const QPixmap &pixmap )
- { return QToolButton::setIcon( pixmap ); }
+ virtual void setIcon( const TQPixmap &pixmap )
+ { return TQToolButton::setIcon( pixmap ); }
/**
* Set the pixmaps for this toolbar button from a QIconSet.
* If you call this you don't need to call any of the other methods
* that set icons or pixmaps.
* @param iconset The iconset to use
*/
- virtual void setIconSet( const QIconSet &iconset );
+ virtual void setIconSet( const TQIconSet &iconset );
#ifndef KDE_NO_COMPAT
/**
@@ -160,7 +160,7 @@ public:
* @param generate If true, then the other icons are automagically
* generated from this one
*/
- void setIcon(const QString &icon, bool /*generate*/ ) { setIcon( icon ); }
+ void setIcon(const TQString &icon, bool /*generate*/ ) { setIcon( icon ); }
/**
* @deprecated
@@ -169,7 +169,7 @@ public:
*
* @param icon The icon to use as the default (normal) one
*/
- void setDefaultIcon(const QString& icon);
+ void setDefaultIcon(const TQString& icon);
/**
* @deprecated
@@ -178,7 +178,7 @@ public:
*
* @param icon The icon to use when disabled
*/
- void setDisabledIcon(const QString& icon);
+ void setDisabledIcon(const TQString& icon);
#endif
/**
@@ -205,7 +205,7 @@ public:
/**
* Return a pointer to this button's popup menu (if it exists)
*/
- QPopupMenu *popup();
+ TQPopupMenu *popup();
/**
* Give this button a popup menu. There will not be a delay when
@@ -219,7 +219,7 @@ public:
* @param p The new popup menu
* @param toggle if true, makes the button "sticky" (toggled)
*/
- void setPopup (QPopupMenu *p, bool toggle = false);
+ void setPopup (TQPopupMenu *p, bool toggle = false);
/**
* Gives this button a delayed popup menu.
@@ -235,7 +235,7 @@ public:
* @param p the new popup menu
* @param toggle if true, makes the button "sticky" (toggled)
*/
- void setDelayedPopup(QPopupMenu *p, bool toggle = false);
+ void setDelayedPopup(TQPopupMenu *p, bool toggle = false);
/**
* Turn this button into a radio button
@@ -268,18 +268,18 @@ public slots:
* orientation changing, etc.
*/
void modeChange();
- virtual void setTextLabel(const QString&, bool tipToo);
+ virtual void setTextLabel(const TQString&, bool tipToo);
protected:
- void paletteChange(const QPalette &);
- void leaveEvent(QEvent *e);
- void enterEvent(QEvent *e);
- void drawButton(QPainter *p);
- bool eventFilter (QObject *o, QEvent *e);
+ void paletteChange(const TQPalette &);
+ void leaveEvent(TQEvent *e);
+ void enterEvent(TQEvent *e);
+ void drawButton(TQPainter *p);
+ bool eventFilter (TQObject *o, TQEvent *e);
void showMenu();
- QSize sizeHint() const;
- QSize minimumSizeHint() const;
- QSize minimumSize() const;
+ TQSize sizeHint() const;
+ TQSize minimumSizeHint() const;
+ TQSize minimumSize() const;
bool isRaised() const;
bool isActive() const;
@@ -303,7 +303,7 @@ private:
* @internal
* @version $Id: ktoolbarbutton.h,v 1.21.2.1 2002/04/28 20:59:16 wtrobin Exp $
*/
-class KToolBarButtonList : public QIntDict<KToolBarButton>
+class KToolBarButtonList : public TQIntDict<KToolBarButton>
{
public:
KToolBarButtonList();
@@ -135,18 +135,18 @@ public:
/**
- * Set the pixmaps for this toolbar button from a QIconSet.
+ * Set the pixmaps for this toolbar button from a TQIconSet.
* If you call this you don't need to call any of the other methods
* that set icons or pixmaps.
diff --git a/extra/kde301/kurifilter.h b/extra/kde301/kurifilter.h
index b013817..d82786a 100644
--- a/extra/kde301/kurifilter.h
+++ b/extra/kde301/kurifilter.h
@@ -29,20 +29,20 @@
class KURIFilterPrivate;
class KURIFilterDataPrivate;
-class QStringList;
+class TQStringList;
class KCModule;
/**
* This is a basic message object used for exchanging filtering
* information between the filter plugins and the application
-* whenever the application requires more information about the
+* whenever the application retquires more information about the
* URI than just a filtered version of it. Any application can
* create an instance of this class and send it to @ref KURIFilter
* to have the filter plugins fill the necessary information.
*
* @sect Example
* <pre>
-* QString text = "kde.org";
+* TQString text = "kde.org";
* KURIFilterData d = text;
* bool filtered = KURIFilter::self()->filter( d );
* if( filtered )
@@ -105,7 +105,7 @@ public:
*
* @param url is the string to be filtered.
*/
- KURIFilterData( const QString& url ) { init( url ); }
+ KURIFilterData( const TQString& url ) { init( url ); }
/**
* Copy constructor.
@@ -149,11 +149,11 @@ public:
* This functions returns the error message set
* by the plugin whenever the uri type is set to
* KURIFilterData::ERROR. Otherwise, it returns
- * a QString::null.
+ * a TQString::null.
*
* @return the error message or a NULL when there is none.
*/
- QString errorMsg() const { return m_strErrMsg; }
+ TQString errorMsg() const { return m_strErrMsg; }
/**
* Returns the URI type.
@@ -172,7 +172,7 @@ public:
*
* @param url the string to be filtered.
*/
- void setData( const QString& url ) { init( url ); }
+ void setData( const TQString& url ) { init( url ); }
/**
* Same as above except the argument is a URL.
@@ -201,12 +201,12 @@ public:
* @param abs_path the abolute path to the local resource.
* @return true if absolute path is successfully set. Otherwise, false.
*/
- bool setAbsolutePath( const QString& /* abs_path */ );
+ bool setAbsolutePath( const TQString& /* abs_path */ );
/**
* Returns the absolute path if one has already been set.
*/
- QString absolutePath() const;
+ TQString absolutePath() const;
/**
* Returns true if the supplied data has an absolute path.
@@ -217,9 +217,9 @@ public:
* Returns the command line options and arguments for a
* local resource when present.
*
* @return options and arguments when present, otherwise QString::null
*/
- QString argsAndOptions() const;
+ TQString argsAndOptions() const;
/**
* Returns true if the current data is a local resource with
@@ -237,7 +237,7 @@ public:
*
* @return the name of the icon associated with the resource
*/
- QString iconName();
+ TQString iconName();
/**
* Overloaded assigenment operator.
@@ -252,26 +252,26 @@ public:
/**
* Overloaded assigenment operator.
*
* This function allows you to easily assign a QString
* to a KURIFilterData object.
*
* @return an instance of a KURIFilterData object.
*/
- KURIFilterData& operator=( const QString& url ) { init( url ); return *this; }
+ KURIFilterData& operator=( const TQString& url ) { init( url ); return *this; }
protected:
/**
* Initializes the KURIFilterData on construction.
*/
- void init( const KURL& url = QString::null );
+ void init( const KURL& url = TQString::null );
private:
bool m_bFiltered;
bool m_bChanged;
- QString m_strErrMsg;
- QString m_strIconName;
+ TQString m_strErrMsg;
+ TQString m_strIconName;
KURL m_pURI;
URITypes m_iType;
@@ -293,7 +293,7 @@ private:
*
* @short Abstract class for URI filter plugins.
*/
-class KURIFilterPlugin : public QObject
+class KURIFilterPlugin : public TQObject
{
Q_OBJECT
@@ -307,14 +307,14 @@ public:
* @param name the name of the plugin.
* @param pri the priority of the plugin.
*/
- KURIFilterPlugin( QObject *parent = 0, const char *name = 0, double pri = 1.0 );
+ KURIFilterPlugin( TQObject *parent = 0, const char *name = 0, double pri = 1.0 );
/**
* Returns the filter's name.
*
* @return A string naming the filter.
*/
- virtual QString name() const { return m_strName; }
+ virtual TQString name() const { return m_strName; }
/**
* Returns the filter's priority.
@@ -342,14 +342,14 @@ public:
*
* @return A configuration module, @p null if the filter isn't configurable.
*/
- virtual KCModule *configModule( QWidget*, const char* ) const { return 0; }
+ virtual KCModule *configModule( TQWidget*, const char* ) const { return 0; }
/**
* Returns the name of the configuration module for the filter.
*
* @return the name of a configuration module or @p null if none.
*/
- virtual QString configName() const { return name(); }
+ virtual TQString configName() const { return name(); }
protected:
@@ -361,7 +361,7 @@ protected:
/**
* Sets the error message in @p data to @p errormsg.
*/
- void setErrorMsg ( KURIFilterData& data, const QString& errmsg ) const {
+ void setErrorMsg ( KURIFilterData& data, const TQString& errmsg ) const {
data.m_strErrMsg = errmsg;
}
@@ -377,9 +377,9 @@ protected:
* Sets the arguments and options string in @p data
* to @p args if any were found during filterting.
*/
- void setArguments( KURIFilterData& data, const QString& args ) const;
+ void setArguments( KURIFilterData& data, const TQString& args ) const;
- QString m_strName;
+ TQString m_strName;
double m_dblPriority;
protected:
@@ -389,7 +389,7 @@ private:
};
-class KURIFilterPluginList : public QPtrList<KURIFilterPlugin>
+class KURIFilterPluginList : public TQPtrList<KURIFilterPlugin>
{
public:
virtual int compareItems(Item a, Item b)
@@ -440,7 +440,7 @@ private:
* simply invoke the corresponding function to obtain
* the filtered string or URL instead of a boolean flag:
* <pre>
- * QString u = KURIFilter::self()->filteredURI( "kde.org" );
+ * TQString u = KURIFilter::self()->filteredURI( "kde.org" );
* </pre>
*
* You can also specify only specific filter(s) to be applied
@@ -450,10 +450,10 @@ private:
* enteries in the \".desktop\" files. Here are a couple of
* examples:
* <pre>
- * QString text = "kde.org";
+ * TQString text = "kde.org";
* bool filtered = KURIFilter::self()->filterURI( text, "KShortURIFilter" );
*
- * QStringList list;
+ * TQStringList list;
* list << "KShortURIFilter" << "MyFilter";
* bool filtered = KURIFilter::self()->filterURI( text, list );
* </pre>
@@ -492,7 +492,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( KURIFilterData& data, const QStringList& filters = QStringList() );
+ bool filterURI( KURIFilterData& data, const TQStringList& filters = TQStringList() );
/**
* Filters the URI given by the URL.
@@ -507,7 +507,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( KURL &uri, const QStringList& filters = QStringList() );
+ bool filterURI( KURL &uri, const TQStringList& filters = TQStringList() );
/**
* Filters a string representing a URI.
@@ -522,7 +522,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( QString &uri, const QStringList& filters = QStringList() );
+ bool filterURI( TQString &uri, const TQStringList& filters = TQStringList() );
/**
* Returns the filtered URI.
@@ -537,7 +537,7 @@ public:
*
* @return the filtered URI or null if it cannot be filtered
*/
- KURL filteredURI( const KURL &uri, const QStringList& filters = QStringList() );
+ KURL filteredURI( const KURL &uri, const TQStringList& filters = TQStringList() );
/**
* Return a filtered string representation of a URI.
@@ -552,7 +552,7 @@ public:
*
* @return the filtered URI or null if it cannot be filtered
*/
- QString filteredURI( const QString &uri, const QStringList& filters = QStringList() );
+ TQString filteredURI( const TQString &uri, const TQStringList& filters = TQStringList() );
/**
* Return an iterator to iterate over all loaded
@@ -560,7 +560,7 @@ public:
*
* @return a plugin iterator.
*/
- QPtrListIterator<KURIFilterPlugin> pluginsIterator() const;
+ TQPtrListIterator<KURIFilterPlugin> pluginsIterator() const;
protected:
@@ -217,9 +217,9 @@ public:
* local resource when present.
*
- * @return options and arguments when present, otherwise QString::null
+ * @return options and arguments when present, otherwise TQString::null
*/
@@ -252,26 +252,26 @@ public:
* Overloaded assigenment operator.
*
- * This function allows you to easily assign a QString
+ * This function allows you to easily assign a TQString
* to a KURIFilterData object.
*